@@ -7,17 +7,22 @@ IOB = "IOB"
 BOLUS_BG = "BOLUS_BG"
 CGM = "CGM"
 PUMP_EVENTS = "PUMP_EVENTS"
+PUMP_EVENTS_BASAL_SUSPENSION = "PUMP_EVENTS_BASAL_SUSPENSION"
+PROFILES = "PROFILES"
 
 DEFAULT_FEATURES = [
     BASAL,
-    BOLUS
+    BOLUS,
+    PUMP_EVENTS
 ]
 
 ALL_FEATURES = [
     BASAL,
     BOLUS,
     IOB,
-    PUMP_EVENTS
+    PUMP_EVENTS,
+    PUMP_EVENTS_BASAL_SUSPENSION,
+    PROFILES
 ]
 
 
